ENActivityHandler

Type Alias ENActivityHandler 

pub type ENActivityHandler = *mut DynBlock<dyn Fn(ENActivityFlags)>;
Available on crate features ENManager and block2 only.
Invoked after the app is launched to report activities that occurred while the app might not be running.

See also Apple’s documentation