ENGetExposureInfoHandler

Type Alias ENGetExposureInfoHandler 

pub type ENGetExposureInfoHandler = *mut DynBlock<dyn Fn(*mut NSArray<ENExposureInfo>, *mut NSError)>;
Available on crate features ENCommon and ENManager and block2 only.
Invoked when getting exposures completes. It provides info about each exposure. If it completes successfully, exposures will contain info about each exposure and error will be nil. If it fails, exposures will be nil and error indicates the reason it failed.

See also Apple’s documentation