pub type ENDetectExposuresHandler = *mut DynBlock<dyn Fn(*mut ENExposureDetectionSummary, *mut NSError)>;Available on crate features
ENCommon and ENManager and block2 only.Expand description
Invoked when detecting exposures completes. It provides a summary of exposures. If it completes successfully, summary will contain a summary of exposures and error will be nil. If it fails, summary will be nil and error indicates the reason it failed.
See also Appleās documentation